==> web-6.0.0.tgz: package/lib/tableList/TabList.js <==
import * as React from "react";
import * as Immutable from "immutable";
import TabView from './TabView';
import { GroupCols } from './GroupCols';
import { Empty } from "../my-icon/index";
import PageSize from './PageSize';
const compareFn = (a, b) => a - b;
const tableInitData = (data, defaulSel, idField) => {
    const defaulSelArr = `${defaulSel}`.split(",");
    return Immutable.fromJS(data, (_key, val, _path) => {
        if (Immutable.isKeyed(val)) {
            let obj = val.toOrderedMap();
            const id = val.get(idField);
            obj = obj.set("checked", defaulSelArr.includes(`${id}`));
            return obj;
        }
        else {
            return val.toList();
        }
    });
};
class TabList extends React.PureComponent {
    constructor(props) {
        super(props);
        this.tabMainTabBodyDomArr = [];
        this.setTabBodyDom = (dom, index) => {
            this.tabMainTabBodyDomArr[index] = dom;
        };
        this.changeScrollTop = (top, index) => {
            this.tabMainTabBodyDomArr.map((val, oindex) => {
                if (oindex !== index) {
                    val.scrollTop = top;
                }
            });
        };
        this.changeState = (path, key) => {
            const index = ~~path - 1;
            if (key === 'active') {
                this.setState(pre => {
                    const data = pre.immutabData.updateIn([index], node => {
                        const status = node.get('checked');
                        return node.set('checked', !status);
                    });
                    const pageData = this.getDataByPageAndPerNum(pre.curPage, pre.perNums, data);
                    return {
                        immutabData: data,
                        tableData: pageData
                    };
                });
            }
            else if (key === "checkPar") {
                const { noPageNums } = this.props;
                this.setState(pre => {
                    const { curPage, perNums, immutabData } = pre;
                    let num;
                    if (!noPageNums) {
                        const rest = curPage * perNums - immutabData.size;
                        num = rest > 0 ? perNums - rest : perNums;
                    }
                    else {
                        num = immutabData.size;
                    }
                    let newData = pre.immutabData;
                    Array.from({ length: num }).forEach((_val, index) => {
                        newData = newData.updateIn([index + (curPage - 1) * perNums], val => {
                            return val.set("checked", path !== "true");
                        });
                    });
                    return {
                        immutabData: newData,
                        tableData: this.getDataByPageAndPerNum(curPage, perNums, newData)
                    };
                });
            }
        };
        this.changePageHandle = (key, val) => {
            if (key === "curPage") {
                this.setState(pre => {
                    const perNums = pre.perNums;
                    return {
                        curPage: val,
                        tableData: this.getDataByPageAndPerNum(val, perNums, pre.immutabData)
                    };
                }, () => {
                    this.setDom();
                });
            }
            else if (key === "perNums") {
                this.setState(pre => {
                    return {
                        perNums: val,
                        curPage: 1,
                        tableData: this.getDataByPageAndPerNum(1, val, pre.immutabData)
                    };
                }, () => {
                    this.setDom();
                });
            }
        };
        const { children, data, idField, defaultSel, initSelectVal, noPageNums } = this.props;
        this.fieldArr = this.getFieldArr(children);
        const immutabData = tableInitData(data, defaultSel, idField);
        this.fixObj = this.initFixObj();
        this.state = {
            immutabData,
            preData: data,
            selectArr: Immutable.List(),
            preInitSelect: initSelectVal,
            perNums: 20,
            curPage: 1,
            tableData: noPageNums ? immutabData : this.getDataByPageAndPerNum(1, 20, immutabData)
        };
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.data !== preState.preData || nextProps.initSelectVal !== preState.preInitSelect) {
            const newData = nextProps.data;
            const { idField } = nextProps;
            const defaultSel = nextProps.initSelectVal ? nextProps.initSelectVal.id : nextProps.defaultSel;
            const data = tableInitData(newData, defaultSel, idField);
            return {
                preData: newData,
                immutabData: data,
                selectArr: Immutable.List([]),
                curPage: 1,
            };
        }
        else {
            return null;
        }
    }
    getDataByPageAndPerNum(curPage, perNums, immutabData) {
        const startIndex = (curPage - 1) * perNums;
        return immutabData.slice(startIndex, perNums + startIndex);
    }
    getFieldArr(arr) {
        const { noOrder, multiply } = this.props;
        return React.Children.map(arr, function (val, index) {
            const { children, forzen, } = val.props;
            let widTotal = 0;
            const child = React.Children.map(children, function (node) {
                const { children, width, field, formatter, align } = node.props;
                widTotal += width;
                return {
                    width, field, formatter, text: children, align
                };
            });
            if (!noOrder && index === 0) {
                const orderCol = {
                    width: 60,
                    field: "order",
                    text: '序号',
                    formatter: undefined,
                    align: 'center'
                };
                child.unshift(orderCol);
                widTotal += 60;
            }
            if (multiply && index === 0) {
                const checkCol = {
                    width: 60,
                    field: "check",
                    text: '全选',
                    formatter: undefined,
                    align: 'center'
                };
                child.unshift(checkCol);
                widTotal += 60;
            }
            return {
                child,
                width: widTotal,
                forzen
            };
        });
    }
    initFixObj() {
        const { tabField, idField, multiply, defaultSel, emptyTxt, noOrder } = this.props;
        return {
            tabField: tabField,
            emptyTxt: emptyTxt,
            idField: idField,
            multiply,
            noOrder,
            defaultSel: defaultSel,
        };
    }
    setSameH() {
        let domArr = this.tabMainTabBodyDomArr;
        if (domArr.length < 2) {
            return;
        }
        const tabDom = domArr.map(val => {
            return val.firstElementChild;
        });
        const tabHArr = tabDom.map(val => val.clientHeight).sort(compareFn);
        const tabHMax = tabHArr[tabHArr.length - 1];
        if (tabHArr[0] !== tabHMax) {
            const trDomArr = tabDom.map(val => val.lastElementChild.children);
            [...trDomArr[0]].forEach((_val, index) => {
                const trCompareDom = trDomArr.map(val => {
                    return val[index];
                });
                const trHArr = trCompareDom.map(val => val.clientHeight).sort(compareFn);
                const trHMax = trHArr[trHArr.length - 1];
                if (trHMax !== trHArr[0]) {
                    trCompareDom.forEach(element => {
                        [...element.children].forEach(td => {
                            td.style.height = `${trHMax}px`;
                        });
                    });
                }
            });
        }
    }
    setDom() {
        this.setSameH();
        this.setTabViewBottomFixHeight();
    }
    viewMap() {
        const { tableData, perNums, curPage } = this.state;
        const startIndex = (curPage - 1) * perNums;
        return this.fieldArr.map((group, index) => {
            return (React.createElement(TabView, { config: group, key: index, setTabBodyDom: this.setTabBodyDom, changeScrollTop: this.changeScrollTop, data: tableData, viewIndex: index, startIndex: startIndex, changeState: this.changeState, fixObj: this.fixObj }));
        });
    }
    componentDidMount() {
        this.setDom();
    }
    setTabViewBottomFixHeight() {
        const arr = this.fieldArr;
        const res = this.tabMainTabBodyDomArr.findIndex((val, index) => {
            let status = false;
            if (!arr[index].forzen) {
                status = val.scrollWidth > val.clientWidth;
            }
            return status;
        });
        if (res !== -1) {
            this.tabMainTabBodyDomArr.forEach((val, index) => {
                if (arr[index].forzen) {
                    val.classList.add('tab-over-wid');
                }
                else if (res !== index) {
                    if (val.scrollWidth <= val.clientWidth) {
                        val.classList.add('tab-over-wid');
                    }
                }
            });
        }
        else {
            this.tabMainTabBodyDomArr.forEach((val) => {
                val.classList.remove('tab-over-wid');
            });
        }
    }
    render() {
        const { height, emptyTxt, noPageNums } = this.props;
        const { immutabData, curPage, perNums } = this.state;
        const hasData = !!immutabData.size;
        const body = hasData ? this.viewMap() : React.createElement(Empty, { txt: emptyTxt });
        const totalPages = Math.ceil(immutabData.size / perNums);
        const page = !noPageNums ? (React.createElement(PageSize, { curPage: curPage, perNums: perNums, totalNums: immutabData.size, totalPages: totalPages, changeHandle: this.changePageHandle })) : undefined;
        return (React.createElement("div", { className: "treeTap-wrap", style: { height: height, } },
            React.createElement("div", { className: "treeTab" }, body),
            page));
    }
}
TabList.defaultProps = {
    height: 300
};
export { TabList, GroupCols };

==> web-7.0.0.tgz: package/lib/tableList/TabList.js <==
import * as React from "react";
import * as Immutable from "immutable";
import TabView from './TabView';
import { GroupCols } from './GroupCols';
import { Empty } from "../my-icon/index";
import PageSize from './PageSize';
const compareFn = (a, b) => a - b;
const tableInitData = (data, defaulSel, idField) => {
    const defaulSelArr = `${defaulSel}`.split(",");
    return Immutable.fromJS(data, (_key, val, _path) => {
        if (Immutable.isKeyed(val)) {
            let obj = val.toOrderedMap();
            const id = val.get(idField);
            obj = obj.set("checked", defaulSelArr.includes(`${id}`));
            return obj;
        }
        else {
            return val.toList();
        }
    });
};
class TabList extends React.PureComponent {
    constructor(props) {
        super(props);
        this.tabMainTabBodyDomArr = [];
        this.setTabBodyDom = (dom, index) => {
            this.tabMainTabBodyDomArr[index] = dom;
        };
        this.changeScrollTop = (top, index) => {
            this.tabMainTabBodyDomArr.map((val, oindex) => {
                if (oindex !== index) {
                    val.scrollTop = top;
                }
            });
        };
        this.changeState = (path, key) => {
            const index = ~~path - 1;
            if (key === 'active') {
                this.setState(pre => {
                    const data = pre.immutabData.updateIn([index], node => {
                        const status = node.get('checked');
                        return node.set('checked', !status);
                    });
                    const pageData = this.getDataByPageAndPerNum(pre.curPage, pre.perNums, data);
                    return {
                        immutabData: data,
                        tableData: pageData
                    };
                });
            }
            else if (key === "checkPar") {
                const { noPageNums } = this.props;
                this.setState(pre => {
                    const { curPage, perNums, immutabData } = pre;
                    let num;
                    if (!noPageNums) {
                        const rest = curPage * perNums - immutabData.size;
                        num = rest > 0 ? perNums - rest : perNums;
                    }
                    else {
                        num = immutabData.size;
                    }
                    let newData = pre.immutabData;
                    Array.from({ length: num }).forEach((_val, index) => {
                        newData = newData.updateIn([index + (curPage - 1) * perNums], val => {
                            return val.set("checked", path !== "true");
                        });
                    });
                    return {
                        immutabData: newData,
                        tableData: this.getDataByPageAndPerNum(curPage, perNums, newData)
                    };
                });
            }
        };
        this.changePageHandle = (key, val) => {
            if (key === "curPage") {
                this.setState(pre => {
                    const perNums = pre.perNums;
                    return {
                        curPage: val,
                        tableData: this.getDataByPageAndPerNum(val, perNums, pre.immutabData)
                    };
                }, () => {
                    this.setDom();
                });
            }
            else if (key === "perNums") {
                this.setState(pre => {
                    return {
                        perNums: val,
                        curPage: 1,
                        tableData: this.getDataByPageAndPerNum(1, val, pre.immutabData)
                    };
                }, () => {
                    this.setDom();
                });
            }
        };
        const { children, data, idField, defaultSel, initSelectVal, noPageNums } = this.props;
        this.fieldArr = this.getFieldArr(children);
        const immutabData = tableInitData(data, defaultSel, idField);
        this.fixObj = this.initFixObj();
        this.state = {
            immutabData,
            preData: data,
            selectArr: Immutable.List(),
            preInitSelect: initSelectVal,
            perNums: 20,
            curPage: 1,
            tableData: noPageNums ? immutabData : this.getDataByPageAndPerNum(1, 20, immutabData)
        };
    }
    static getDerivedStateFromProps(nextProps, preState) {
        if (nextProps.data !== preState.preData || nextProps.initSelectVal !== preState.preInitSelect) {
            const newData = nextProps.data;
            const { idField } = nextProps;
            const defaultSel = nextProps.initSelectVal ? nextProps.initSelectVal.id : nextProps.defaultSel;
            const data = tableInitData(newData, defaultSel, idField);
            return {
                preData: newData,
                immutabData: data,
                selectArr: Immutable.List([]),
                curPage: 1,
            };
        }
        else {
            return null;
        }
    }
    getDataByPageAndPerNum(curPage, perNums, immutabData) {
        const startIndex = (curPage - 1) * perNums;
        return immutabData.slice(startIndex, perNums + startIndex);
    }
    getFieldArr(arr) {
        const { noOrder, multiply } = this.props;
        return React.Children.map(arr, function (val, index) {
            const { children, forzen, } = val.props;
            let widTotal = 0;
            const child = React.Children.map(children, function (node) {
                const { children, width, field, formatter, align } = node.props;
                widTotal += width;
                return {
                    width, field, formatter, text: children, align
                };
            });
            if (!noOrder && index === 0) {
                const orderCol = {
                    width: 60,
                    field: "order",
                    text: '序号',
                    formatter: undefined,
                    align: 'center'
                };
                child.unshift(orderCol);
                widTotal += 60;
            }
            if (multiply && index === 0) {
                const checkCol = {
                    width: 60,
                    field: "check",
                    text: '全选',
                    formatter: undefined,
                    align: 'center'
                };
                child.unshift(checkCol);
                widTotal += 60;
            }
            return {
                child,
                width: widTotal,
                forzen
            };
        });
    }
    initFixObj() {
        const { tabField, idField, multiply, defaultSel, emptyTxt, noOrder } = this.props;
        return {
            tabField: tabField,
            emptyTxt: emptyTxt,
            idField: idField,
            multiply,
            noOrder,
            defaultSel: defaultSel,
        };
    }
    setSameH() {
        let domArr = this.tabMainTabBodyDomArr;
        if (domArr.length < 2) {
            return;
        }
        const tabDom = domArr.map(val => {
            return val.firstElementChild;
        });
        const tabHArr = tabDom.map(val => val.clientHeight).sort(compareFn);
        const tabHMax = tabHArr[tabHArr.length - 1];
        if (tabHArr[0] !== tabHMax) {
            const trDomArr = tabDom.map(val => val.lastElementChild.children);
            [...trDomArr[0]].forEach((_val, index) => {
                const trCompareDom = trDomArr.map(val => {
                    return val[index];
                });
                const trHArr = trCompareDom.map(val => val.clientHeight).sort(compareFn);
                const trHMax = trHArr[trHArr.length - 1];
                if (trHMax !== trHArr[0]) {
                    trCompareDom.forEach(element => {
                        [...element.children].forEach(td => {
                            td.style.height = `${trHMax}px`;
                        });
                    });
                }
            });
        }
    }
    setDom() {
        this.setSameH();
        this.setTabViewBottomFixHeight();
    }
    viewMap() {
        const { tableData, perNums, curPage } = this.state;
        const startIndex = (curPage - 1) * perNums;
        return this.fieldArr.map((group, index) => {
            return (React.createElement(TabView, { config: group, key: index, setTabBodyDom: this.setTabBodyDom, changeScrollTop: this.changeScrollTop, data: tableData, viewIndex: index, startIndex: startIndex, changeState: this.changeState, fixObj: this.fixObj }));
        });
    }
    componentDidMount() {
        this.setDom();
    }
    setTabViewBottomFixHeight() {
        const arr = this.fieldArr;
        const res = this.tabMainTabBodyDomArr.findIndex((val, index) => {
            let status = false;
            if (!arr[index].forzen) {
                status = val.scrollWidth > val.clientWidth;
            }
            return status;
        });
        if (res !== -1) {
            this.tabMainTabBodyDomArr.forEach((val, index) => {
                if (arr[index].forzen) {
                    val.classList.add('tab-over-wid');
                }
                else if (res !== index) {
                    if (val.scrollWidth <= val.clientWidth) {
                        val.classList.add('tab-over-wid');
                    }
                }
            });
        }
        else {
            this.tabMainTabBodyDomArr.forEach((val) => {
                val.classList.remove('tab-over-wid');
            });
        }
    }
    render() {
        const { height, emptyTxt, noPageNums } = this.props;
        const { immutabData, curPage, perNums } = this.state;
        const hasData = !!immutabData.size;
        const body = hasData ? this.viewMap() : React.createElement(Empty, { txt: emptyTxt });
        const totalPages = Math.ceil(immutabData.size / perNums);
        const page = !noPageNums ? (React.createElement(PageSize, { curPage: curPage, perNums: perNums, totalNums: immutabData.size, totalPages: totalPages, changeHandle: this.changePageHandle })) : undefined;
        const styleObj = height ? { height: height, } : undefined;
        return (React.createElement("div", { className: "treeTap-wrap", style: styleObj },
            React.createElement("div", { className: "treeTab" }, body),
            page));
    }
}
TabList.defaultProps = {
    height: 300
};
export { TabList, GroupCols };
